==> nm-tray_0.4.3.orig.tar.gz: nm-tray-0.4.3/translations/nm-tray_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Verbindungsinformationen</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <source>Dialog</source>
        <translatorcomment>Did not translate as &quot;Dialog&quot; seems to get replaced with string &quot;nm-tray info&quot; from context &quot;Tray&quot;.</translatorcomment>
        <translation type="vanished">Dialog</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Verfügbare Informationen</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Aktive Verbindungen</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Verfügbare drahtlose Verbindungen</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="744"/>
        <source>root</source>
        <translatorcomment>Translated as &quot;network&quot; hence not literally at all. Not sure what&apos;s best here but this seems a bit more reasonable to me.</translatorcomment>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="746"/>
        <source>active connection(s)</source>
        <translation>Aktive Verbindungen</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="748"/>
        <source>connection(s)</source>
        <translation>Verbindung(en)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="750"/>
        <source>device(s)</source>
        <translation>Gerät(e)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="752"/>
        <source>wifi network(s)</source>
        <translation>WLAN-Netzwerk(e)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1043"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="55"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-Tray - WLAN-Passwort</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Passwort wird für die Verbindung zu „%1“ benötigt:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1151"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Allgemeines</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Schnittstelle</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1154"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Hardware-Adresse</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1156"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Treiber</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1158"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Übertragungsrate</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1160"/>
        <source> Kb/s</source>
        <translation> Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1162"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1166"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1170"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1171"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1182"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1184"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Subnetzmaske</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1193"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Standardroute</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1199"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation>DNS(%1)</translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Die Verbindung wurde unterbrochen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Verbindung hergestellt</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation>NetworkManager (nm-Tray)</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Netzwerk aktivieren</translation>
    </message>
    <message>
        <source>Enable Wi-fi</source>
        <translation type="vanished">Drahtlose Verbindungen aktivieren</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Verbindung &lt;strong&gt;%1&lt;/strong&gt;(%2) aktiv&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Keine aktive Verbindung &lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Nicht mehr verbunden mit %1 „%2“.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Jetzt verbunden mit %1 „%2“.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>WLAN aktivieren</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Benachrichtigungen aktivieren</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Verbindungsinformationen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Debuginformationen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>WLAN - Scan anfordern</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Verbindungen bearbeiten …</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>%1 über</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;&gt;&lt;/strong&gt; ist ein einfaches Qt-basiertes Frontend für den &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</translation>
    </message>
    <message>
        <source>This is the about nm-tray!</source>
        <translatorcomment>Pimped this a little bit. Hope that&apos;s okay.</translatorcomment>
        <translation type="obsolete">nm-tray ist eine auf Qt basierende Nutzeroberfläche für den NetworkManager zur Ausführung in der Leiste von Desktop-Umgebungen.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>nm-tray Informationen</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Aktive Verbindungen</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>WLAN-Netzwerk(e)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Bekannte Verbindung(en)</translation>
    </message>
</context>
</TS>

==> nm-tray-0.5.1.tar.gz: nm-tray-0.5.1/translations/nm-tray_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Verbindungsinformationen</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <source>Dialog</source>
        <translatorcomment>Did not translate as &quot;Dialog&quot; seems to get replaced with string &quot;nm-tray info&quot; from context &quot;Tray&quot;.</translatorcomment>
        <translation type="vanished">Dialog</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Verfügbare Informationen</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Aktive Verbindungen</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Verfügbare drahtlose Verbindungen</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="745"/>
        <source>root</source>
        <translatorcomment>Translated as &quot;network&quot; hence not literally at all. Not sure what&apos;s best here but this seems a bit more reasonable to me.</translatorcomment>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="747"/>
        <source>active connection(s)</source>
        <translation>Aktive Verbindungen</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="749"/>
        <source>connection(s)</source>
        <translation>Verbindung(en)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="751"/>
        <source>device(s)</source>
        <translation>Gerät(e)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="753"/>
        <source>wifi network(s)</source>
        <translation>WLAN-Netzwerk(e)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1044"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-Tray - WLAN-Passwort</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="57"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Passwort wird für die Verbindung zu „%1“ benötigt:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Allgemeines</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1153"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Schnittstelle</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1155"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Hardware-Adresse</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1157"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Treiber</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1159"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Übertragungsrate</translation>
    </message>
    <message>
        <source> Kb/s</source>
        <translation type="vanished"> Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1163"/>
        <source>Kb/s</source>
        <translation>Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1165"/>
        <source>Mb/s</source>
        <translation>Mb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1167"/>
        <source>Gb/s</source>
        <translation>Gb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1169"/>
        <source>Tb/s</source>
        <translation>Tb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1172"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1176"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1180"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1181"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1192"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1194"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Subnetzmaske</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1203"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Standardroute</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1209"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation>DNS(%1)</translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Die Verbindung wurde unterbrochen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Verbindung hergestellt</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation>NetworkManager (nm-Tray)</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Netzwerk aktivieren</translation>
    </message>
    <message>
        <source>Enable Wi-fi</source>
        <translation type="vanished">Drahtlose Verbindungen aktivieren</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Verbindung &lt;strong&gt;%1&lt;/strong&gt;(%2) aktiv&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Keine aktive Verbindung &lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Nicht mehr verbunden mit %1 „%2“.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Jetzt verbunden mit %1 „%2“.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>WLAN aktivieren</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Benachrichtigungen aktivieren</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Verbindungsinformationen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Debuginformationen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>WLAN - Scan anfordern</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Verbindungen bearbeiten …</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>%1 über</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;&gt;&lt;/strong&gt; ist ein einfaches Qt-basiertes Frontend für den &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</translation>
    </message>
    <message>
        <source>This is the about nm-tray!</source>
        <translatorcomment>Pimped this a little bit. Hope that&apos;s okay.</translatorcomment>
        <translation type="obsolete">nm-tray ist eine auf Qt basierende Nutzeroberfläche für den NetworkManager zur Ausführung in der Leiste von Desktop-Umgebungen.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>nm-tray Informationen</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Aktive Verbindung(en)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>WLAN-Netzwerk(e)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Bekannte Verbindung(en)</translation>
    </message>
</context>
</TS>
